@@ -1,8 +1,8 @@
 /*
- * $Id: pinboard.c,v 1.176 2004/07/30 17:08:40 tal197 Exp $
+ * $Id: pinboard.c,v 1.186 2005/01/16 16:48:01 tal197 Exp $
  *
  * ROX-Filer, filer for the ROX desktop project
- * Copyright (C) 2003, the ROX-Filer team.
+ * Copyright (C) 2005, the ROX-Filer team.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -150,6 +150,7 @@ static Option o_pinboard_shadow_labels;
 static Option o_blackbox_hack;
 
 static Option o_top_margin, o_bottom_margin;
+static Option o_pinboard_image_scaling;
 
 /* Static prototypes */
 static GType pin_icon_get_type(void);
@@ -259,6 +260,8 @@ void pinboard_init(void)
 	option_add_int(&o_top_margin, "pinboard_top_margin", 0);
 	option_add_int(&o_bottom_margin, "pinboard_bottom_margin", 0);
 
+	option_add_int(&o_pinboard_image_scaling, "pinboard_image_scaling", 0);
+
 	option_add_notify(pinboard_check_options);
 
 	gdk_color_parse(o_pinboard_fg_colour.value, &pin_text_fg_col);
@@ -445,8 +448,9 @@ void pinboard_moved_widget(GtkWidget *widget, const gchar *name,
  * 'x' and 'y' are the coordinates of the point in the middle of the text.
  * 'name' is the name to use. If NULL then the leafname of path is used.
  */
-void pinboard_pin(const gchar *path, const gchar *name, int x, int y,
-		  const gchar *shortcut)
+static void pinboard_pin_with_args(const gchar *path, const gchar *name,
+				   int x, int y, const gchar *shortcut,
+				   const gchar *args)
 {
 	GtkWidget	*align, *vbox;
 	GdkWindow	*events;
@@ -532,11 +536,50 @@ void pinboard_pin(const gchar *path, const gchar *name, int x, int y,
 	pin_icon_set_tip(pi);
 
 	icon_set_shortcut(icon, shortcut);
+	icon_set_arguments(icon, args);
 
 	if (!loading_pinboard)
 		pinboard_save();
 }
 
+void pinboard_pin(const gchar *path, const gchar *name, int x, int y,
+		  const gchar *shortcut)
+{
+	pinboard_pin_with_args(path, name, x, y, shortcut, NULL);
+}
+
+/*
+ * Remove an icon from the background.  The first icon with a matching
+ * path is removed.  If name is not NULL then that also must match
+ */
+gboolean pinboard_remove(const gchar *path, const gchar *name)
+{
+	GList *item;
+	PinIcon		*pi;
+	Icon		*icon;
+
+	g_return_val_if_fail(current_pinboard != NULL, FALSE);
+
+	for(item=current_pinboard->icons; item; item=g_list_next(item)) {
+		pi=(PinIcon *) item->data;
+		icon=(Icon *) pi;
+
+		if(strcmp(icon->path, path)!=0)
+			continue;
+
+		if(name && strcmp(name, icon->item->leafname)!=0)
+			continue;
+
+		icon_destroy(icon);
+	
+		pinboard_save();
+
+		return TRUE;
+	}
+
+	return FALSE;
+}
+
 /* Put a border around the icon, briefly.
  * If icon is NULL then cancel any existing wink.
  * The icon will automatically unhighlight unless timeout is FALSE,
@@ -760,6 +803,9 @@ void pinboard_update_size(void)
 {
 	int width, height;
 
+	if (!current_pinboard)
+		return;
+
 	gtk_window_get_size(GTK_WINDOW(current_pinboard->window),
 			&width, &height);
 	
@@ -895,7 +941,7 @@ static gint end_wink(gpointer data)
 static void set_size_and_style(PinIcon *pi)
 {
 	Icon		*icon = (Icon *) pi;
-	MaskedPixmap	*image = icon->item->image;
+	MaskedPixmap	*image = di_image(icon->item);
 	int		iwidth = image->width;
 	int		iheight = image->height;
 
@@ -915,7 +961,7 @@ static gint draw_icon(GtkWidget *widget, GdkEventExpose *event, PinIcon *pi)
 	static GtkWidgetClass *parent_class = NULL;
 	Icon		*icon = (Icon *) pi;
 	DirItem		*item = icon->item;
-	MaskedPixmap	*image = item->image;
+	MaskedPixmap	*image = di_image(item);
 	int		iwidth = image->width;
 	int		iheight = image->height;
 	int		x, y;
@@ -1153,7 +1199,7 @@ static void perform_action(PinIcon *pi, GdkEventButton *event)
 			pinboard_wink_item(pi, TRUE);
 			if (event->type == GDK_2BUTTON_PRESS)
 				icon_set_selected(icon, FALSE);
-			run_diritem(icon->path, icon->item, NULL, NULL, FALSE);
+			icon_run(icon);
 			break;
 		case ACT_EDIT_ITEM:
 			dnd_motion_ungrab();
@@ -1358,7 +1404,7 @@ static void backdrop_from_xml(xmlNode *node)
 static void pinboard_load_from_xml(xmlDocPtr doc)
 {
 	xmlNodePtr node, root;
-	char	   *tmp, *label, *path, *shortcut;
+	char	   *tmp, *label, *path, *shortcut, *args;
 	int	   x, y;
 
 	root = xmlDocGetRootElement(doc);
@@ -1394,12 +1440,14 @@ static void pinboard_load_from_xml(xmlDocPtr doc)
 		if (!path)
 			path = g_strdup("<missing path>");
 		shortcut = xmlGetProp(node, "shortcut");
+		args = xmlGetProp(node, "args");
 
-		pinboard_pin(path, label, x, y, shortcut);
+		pinboard_pin_with_args(path, label, x, y, shortcut, args);
 
 		g_free(path);
 		g_free(label);
 		g_free(shortcut);
+		g_free(args);
 	}
 }
 
@@ -1505,6 +1553,8 @@ static void pinboard_save(void)
 		xmlSetProp(tree, "label", icon->item->leafname);
 		if (icon->shortcut)
 			xmlSetProp(tree, "shortcut", icon->shortcut);
+		if (icon->args)
+			xmlSetProp(tree, "args", icon->args);
 	}
 
 	save_new = g_strconcat(save, ".new", NULL);
@@ -2196,7 +2246,9 @@ static GdkPixmap *load_backdrop(const gchar *path, BackdropStyle style)
 				MIN(screen_width, width * scale),
 				MIN(screen_height, height * scale),
 				x, y, scale, scale,
-				GDK_INTERP_NEAREST, 255);
+				o_pinboard_image_scaling.int_value?
+				     GDK_INTERP_BILINEAR: GDK_INTERP_HYPER,
+				255);
 		g_object_unref(old);
 	}
 
@@ -2545,6 +2597,11 @@ static void pinboard_reshape_icon(Icon *icon)
 		fixed_move_fast(GTK_FIXED(current_pinboard->fixed),
 				pi->win, x, y);
 	}
+
+	/* Newer versions of GTK seem to need this, or the icon doesn't
+	 * get redrawn.
+	 */
+	gtk_widget_queue_draw(pi->win);
 }
 
 /* Sets the pinboard_font global from the option. Doesn't do anything else. */
