@@ -1,8 +1,8 @@
 /*
- * $Id: run.c,v 1.66 2004/07/30 17:08:41 tal197 Exp $
+ * $Id: run.c,v 1.71 2005/01/16 16:48:02 tal197 Exp $
  *
  * ROX-Filer, filer for the ROX desktop project
- * Copyright (C) 2003, the ROX-Filer team.
+ * Copyright (C) 2005, the ROX-Filer team.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -106,14 +106,14 @@ void run_with_files(const char *path, GList *uri_list)
 	
 	while (uri_list)
 	{
-		const char *uri = uri_list->data;
+		const EscapedPath *uri = uri_list->data;
 		char *local;
 
 		local = get_local_path(uri);
 		if (local) 
 			argv[argc++] = local;
 		else
-			argv[argc++] = g_strdup(uri);
+			argv[argc++] = unescape_uri(uri);
 		uri_list = uri_list->next;
 	}
 	
@@ -191,6 +191,46 @@ void run_with_data(const char *path, gpointer data, gulong length)
 	close(fds[0]);
 }
 
+/* Splits args into an argument vector, and runs the program. Must be
+ * executable.
+ */
+void run_with_args(const char *path, DirItem *item, const char *args)
+{
+	GError *error = NULL;
+	gchar **argv = NULL;
+	int n_args = 0;
+
+	if (item->base_type != TYPE_DIRECTORY && item->base_type != TYPE_FILE)
+	{
+		delayed_error("Arguments (%s) given for non-executable item %s",
+				args, path);
+		return;
+	}
+
+	if (!g_shell_parse_argv(args, &n_args, &argv, &error))
+	{
+		delayed_error("Failed to parse argument string '%s':\n%s",
+				args, error->message);
+		g_error_free(error);
+		return;
+	}
+
+	g_return_if_fail(argv != NULL);
+	g_return_if_fail(error == NULL);
+
+	argv = g_realloc(argv, (n_args + 2) * sizeof(gchar *));
+	memmove(argv + 1, argv, (n_args + 1) * sizeof(gchar *));
+
+	if (item->base_type == TYPE_DIRECTORY)
+		argv[0] = g_strconcat(path, "/AppRun", NULL);
+	else
+		argv[0] = g_strdup(path);
+
+	rox_spawn(home_dir, (const gchar **) argv);
+
+	g_strfreev(argv);
+}
+
 /* Load a file, open a directory or run an application. Or, if 'edit' is set:
  * edit a file, open an application, follow a symlink or mount a device.
  *
