@@ -1,8 +1,8 @@
 /*
- * $Id: type.c,v 1.155 2004/07/08 15:23:22 tal197 Exp $
+ * $Id: type.c,v 1.161 2005/01/16 16:48:03 tal197 Exp $
  *
  * ROX-Filer, filer for the ROX desktop project
- * Copyright (C) 2003, the ROX-Filer team.
+ * Copyright (C) 2005, the ROX-Filer team.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -212,6 +212,23 @@ static MIME_type *get_mime_type(const gchar *type_name, gboolean can_create)
 	return mtype;
 }
 
+/* NULL if we don't know / don't support contents checking */
+MIME_type *mime_type_from_contents(const char *path)
+{
+	MIME_type *type = NULL;
+#ifdef HAVE_GNOME_VFS
+	char *type_name;
+
+	type_name = gnome_vfs_get_mime_type(path);
+	if (type_name)
+	{
+		type = get_mime_type(type_name, TRUE);
+		free(type_name);
+	}
+#endif
+	return type;
+}
+
 const char *basetype_name(DirItem *item)
 {
 	if (item->flags & ITEM_FLAG_SYMLINK)
@@ -299,13 +316,6 @@ MIME_type *type_from_path(const char *path)
 	MIME_type *type = NULL;
 	int	i;
 
-#if 0
-# ifdef WITH_GNOMEVFS
-	if (o_use_gnomevfs.int_value)
-		return get_mime_type(gnome_vfs_mime_type_from_name(path), TRUE);
-# endif
-#endif
-
 	leafname = g_basename(path);
 
 	type = g_hash_table_lookup(literal_hash, leafname);
@@ -858,7 +868,7 @@ void type_set_handler_dialog(MIME_type *type)
 {
 	guchar		*tmp;
 	GtkDialog	*dialog;
-	GtkWidget	*frame, *entry, *label;
+	GtkWidget	*frame, *entry, *label, *button;
 	GtkWidget	*hbox;
 	Radios		*radios;
 
@@ -939,10 +949,11 @@ void type_set_handler_dialog(MIME_type *type)
 		gtk_editable_set_position(GTK_EDITABLE(entry), 0);
 	}
 
-	gtk_dialog_add_buttons(dialog,
-			GTK_STOCK_CANCEL, GTK_RESPONSE_DELETE_EVENT,
-			GTK_STOCK_OK, GTK_RESPONSE_OK,
-			NULL);
+	gtk_dialog_add_button(dialog, GTK_STOCK_CLOSE, GTK_RESPONSE_CANCEL);
+
+	button = button_new_mixed(GTK_STOCK_OK, _("_Use Command"));
+	GTK_WIDGET_SET_FLAGS(button, GTK_CAN_DEFAULT);
+	gtk_dialog_add_action_widget(dialog, button, GTK_RESPONSE_OK);
 
 	hbox = gtk_hbox_new(TRUE, 4);
 	gtk_box_pack_start(GTK_BOX(dialog->vbox), hbox, FALSE, TRUE, 0);
@@ -1161,7 +1172,8 @@ GdkColor *type_get_colour(DirItem *item, GdkColor *normal)
 	if (!o_display_colour_types.int_value)
 		return normal;
 
-	if (item->flags & ITEM_FLAG_EXEC_FILE)
+	if (item->flags & ITEM_FLAG_EXEC_FILE &&
+	    item->mime_type == application_executable)
 		type = TYPE_EXEC;
 	else if (item->flags & ITEM_FLAG_APPDIR)
 		type = TYPE_APPDIR;
